# TaskEx
#### A library for running Python code or shell commands as tasks.

[![PyPI version](https://img.shields.io/pypi/v/taskex?color=blue)](https://pypi.org/project/taskex/)
[![License](https://img.shields.io/github/license/adalundhe/taskex)](https://github.com/adalundhe/taskex/blob/main/LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](https://github.com/adalundhe/taskex/blob/main/CODE_OF_CONDUCT.md)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/taskex?color=red)](https://pypi.org/project/taskex/)


| Package     | TaskEx                                                          |
| ----------- | -----------                                                     |
| Version     | 0.1.8                                                           |
| Download    | https://pypi.org/project/taskex/                                | 
| Source      | https://github.com/adalundhe/taskex                             |
| Keywords    | performance, testing, async, distributed, graph, DAG, workflow  |
